==> orchestra-api-4.0.10-sources.jar: org/ow2/orchestra/facade/data/runtime/PartnerLinkUpdateData.java <==
/**
 * Copyright (C) 2008 Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.facade.data.runtime;

import org.ow2.orchestra.facade.runtime.PartnerLinkUpdateType;
import org.ow2.orchestra.facade.uuid.ActivityInstanceUUID;
import org.w3c.dom.Element;

/**
 *
 * @author Gael Lalire
 */
public class PartnerLinkUpdateData extends ScopeUpdateData {

  private static final long serialVersionUID = -5742308669511705458L;

  protected String name;

  private PartnerLinkUpdateType partnerLinkUpdateType;

  private Element partnerLinkReference;

  public PartnerLinkUpdateData(final ActivityInstanceUUID scopeActivityUUID, final ActivityInstanceUUID activityUUID,
    final String name, final PartnerLinkUpdateType partnerLinkUpdateType, final Element partnerLinkReference) {
    super(scopeActivityUUID, activityUUID);
    this.name = name;
    this.partnerLinkUpdateType = partnerLinkUpdateType;
    this.partnerLinkReference = partnerLinkReference;
  }

  /**
   * @return the name
   */
  public String getName() {
    return name;
  }

  /**
   * @return the partnerLinkUpdateType
   */
  public PartnerLinkUpdateType getPartnerLinkUpdateType() {
    return partnerLinkUpdateType;
  }

  /**
   * @return the partnerLinkReference
   */
  public Element getPartnerLinkReference() {
    return partnerLinkReference;
  }

}

==> orchestra-api-4.3.0-sources.jar: org/ow2/orchestra/facade/data/runtime/PartnerLinkUpdateData.java <==
/**
 * Copyright (C) 2008 Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.facade.data.runtime;

import org.ow2.orchestra.facade.runtime.PartnerLinkUpdateType;
import org.ow2.orchestra.facade.uuid.ActivityInstanceUUID;
import org.w3c.dom.Element;

/**
 *
 * @author Gael Lalire
 */
public class PartnerLinkUpdateData extends ScopeUpdateData {

  protected String name;

  private final PartnerLinkUpdateType partnerLinkUpdateType;

  private final Element partnerLinkReference;

  public PartnerLinkUpdateData(final ActivityInstanceUUID scopeActivityUUID, final ActivityInstanceUUID activityUUID,
    final String name, final PartnerLinkUpdateType partnerLinkUpdateType, final Element partnerLinkReference) {
    super(scopeActivityUUID, activityUUID);
    this.name = name;
    this.partnerLinkUpdateType = partnerLinkUpdateType;
    this.partnerLinkReference = partnerLinkReference;
  }

  /**
   * @return the name
   */
  public String getName() {
    return this.name;
  }

  /**
   * @return the partnerLinkUpdateType
   */
  public PartnerLinkUpdateType getPartnerLinkUpdateType() {
    return this.partnerLinkUpdateType;
  }

  /**
   * @return the partnerLinkReference
   */
  public Element getPartnerLinkReference() {
    return this.partnerLinkReference;
  }

}
